summaryrefslogtreecommitdiffstatshomepage
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/mame/drivers/peplus.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/drivers/peplus.cpp b/src/mame/drivers/peplus.cpp
index 301e437c008..ae8100fb4e8 100644
--- a/src/mame/drivers/peplus.cpp
+++ b/src/mame/drivers/peplus.cpp
@@ -4970,7 +4970,7 @@ PayTable Js+ 2PR 3K STR FL FH 4K SF RF (Bonus)
ROM_LOAD( "cap740.u50", 0x0000, 0x0100, CRC(6fe619c4) SHA1(49e43dafd010ce0fe9b2a63b96a4ddedcb933c6d) )
ROM_END
-ROM_START( pepp0232 ) /* Normal board : Uknown Draw Poker (PP0232) */
+ROM_START( pepp0232 ) /* Normal board : Patriot Poker (PP0232) */
/*
Has 5 additional cards, 10 through Ace, with a US Flag for a Suit.
@@ -14184,7 +14184,7 @@ GAMEL(1987, pepp0223, pepp0127, peplus, peplus_poker, peplus_state, peplus,
GAMEL(1987, pepp0224, pepp0054, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0224) Deuces Wild Poker (set 1)", 0, layout_pe_poker )
GAMEL(1987, pepp0224a, pepp0054, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0224) Deuces Wild Poker (set 2)", 0, layout_pe_poker )
GAMEL(1987, pepp0230, pepp0001, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0230) Standard Draw Poker", 0, layout_pe_poker )
-GAMEL(1987, pepp0232, 0, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0232) Unknown American Draw Poker", 0, layout_pe_poker )
+GAMEL(1987, pepp0232, 0, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0232) Patriot Poker", 0, layout_pe_poker )
GAMEL(1987, pepp0242, pepp0054, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0242) Deuces Wild Poker (International English/Spanish)", 0, layout_pe_poker )
GAMEL(1987, pepp0249, pepp0054, peplus, peplus_poker, peplus_state, nonplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0249) Deuces Wild Poker", 0, layout_pe_poker )
GAMEL(1987, pepp0250, 0, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0250) Double Down Stud Poker (set 1)", 0, layout_pe_poker )
@@ -14198,9 +14198,9 @@ GAMEL(1987, pepp0288, pepp0001, peplus, peplus_poker, peplus_state, peplus,
GAMEL(1987, pepp0290, pepp0054, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0290) Deuces Wild Poker (set 1)", 0, layout_pe_poker )
GAMEL(1987, pepp0290a, pepp0054, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0290) Deuces Wild Poker (set 2)", 0, layout_pe_poker )
GAMEL(1987, pepp0291, pepp0054, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0291) Deuces Wild Poker (set 1)", 0, layout_pe_poker )
+GAMEL(1987, pepp0291a, pepp0054, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0291) Deuces Wild Poker (set 2)", 0, layout_pe_poker )
GAMEL(1987, pepp0294, 0, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0294) Aces and Faces Bonus Joker Poker", 0, layout_pe_poker )
GAMEL(1987, pepp0295, 0, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0295) Super Deuces Wild Poker", 0, layout_pe_poker )
-GAMEL(1987, pepp0291a, pepp0054, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0291) Deuces Wild Poker (set 2)", 0, layout_pe_poker )
GAMEL(1987, pepp0401, pepp0158, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0401) 4 of a Kind Bonus Poker", 0, layout_pe_poker )
GAMEL(1987, pepp0409, pepp0158, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0409) 4 of a Kind Bonus Poker", 0, layout_pe_poker )
GAMEL(1987, pepp0410, pepp0158, peplus, peplus_poker, peplus_state, peplus, ROT0, "IGT - International Game Technology", "Player's Edge Plus (PP0410) 4 of a Kind Bonus Poker (set 1)", 0, layout_pe_poker )